@@ -2,10 +2,11 @@
 utils::globalVariables(c("E<-","G", "G_between", "G_within",
                          "G_between_01", "G_between_10",
                          "G_within_0", "G_within_1", "X", "Y",
+                         "delta", "ind_fixed_effect", "n",
                          "calc_mle2_function", "cidx", "correction",
                          "data_first_step", "endogeneity",  "estimation",
                          "exclusion_restriction", "first_step",
                          "graph.adjacency", "hypothesis", "parnames<-",
                          "mle_controls", "model", "new", "mle2.options", "grad",
                          "hessian", "jacobian", "start.val", "to_weight", "tt",
-                         "unobservables", "w", "y", "z","%>%"))
+                         "unobservables", "w", "y", "z","%>%", "n_fe"))
