@@ -9,7 +9,7 @@ mle_het <- function(y, X, G, z, side, starting.values, boundL, boundU) {
   theta_U <- boundU
 
   if(side == "het_l"){
-    parnames(ll_het_left) <- names(theta)
+    bbmle::parnames(ll_het_left) <- names(theta)
     fit <- mle3(ll_het_left, optimizer = "constrOptim",
                 method = "Nelder-Mead", start = theta, parnames = names(theta),
                 ui = rbind(c(rep(0, length(theta) - 3), - 1, - 1,0),
@@ -20,7 +20,7 @@ mle_het <- function(y, X, G, z, side, starting.values, boundL, boundU) {
                 data = list(Y = y, X = X, G = G, z = z))
 
    } else if (side == "het_r"){
-    parnames(ll_het_right) <- names(theta)
+     bbmle::parnames(ll_het_right) <- names(theta)
     fit <- mle3(ll_het_right, optimizer = "constrOptim",
                 method = "Nelder-Mead", start = theta, parnames = names(theta),
                 ui = rbind(c(rep(0, length(theta) - 3), - 1, - 1, 0),
